@@ -11,10 +11,10 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Author::RWSTAUNER;
-# git description: v4.205-1-g5fb9466
+# git description: v4.206-4-g253a2cf
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
-$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.206';
+$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.207';
 # ABSTRACT: RWSTAUNER's Dist::Zilla config
 
 use Moose;
@@ -159,10 +159,11 @@ has releaser => (
 
 has skip_plugins => (
   is         => 'ro',
-  isa        => 'Str',
+  isa        => 'Maybe[Regexp]',
   lazy       => 1,
   default    => sub {
-    $_[0]->_config(skip_plugins => '');
+    my $skip = $_[0]->_config(skip_plugins => '');
+    return $skip ? qr/$skip/x : undef;
   }
 );
 
@@ -207,7 +208,6 @@ after configure => sub {
 
   # TODO: accept this from ENV
   my $skip = $self->skip_plugins;
-  $skip &&= qr/$skip/;
 
   my $dynamic = $self->payload;
   # sneak this config in behind @TestingMania's back
@@ -244,6 +244,12 @@ after configure => sub {
   }
 };
 
+around add_bundle => sub {
+  my ($orig, $self, $name, @args) = @_;
+  return if $self->skip_plugins && $self->skip_plugins =~ $name;
+  $self->$orig($name, @args);
+};
+
 # Configure plugins.
 sub configure {
   my ($self) = @_;
@@ -545,7 +551,7 @@ Dist::Zilla::PluginBundle::Author::RWSTAUNER - RWSTAUNER's Dist::Zilla config
 
 =head1 VERSION
 
-version 4.206
+version 4.207
 
 =head1 SYNOPSIS
 
